# SRM Autonomous Surface Vehicle Messaging Queue API
------
The team SRMASV uses this repository as an API to transfer data from one process or device to another process or device.

We develop this API by using setuptools for easy installation of this Module within various different computers and developers.
------
### Installation
------
To install just type in the following command:
`python setup.py install`
